package octclipse.launch;

import java.io.BufferedReader;
import java.io.File;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.List;

import octclipse.core.OctaveNature;
import octclipse.core.OctavePlugin;
import org.eclipse.core.runtime.ILog;
import org.eclipse.core.runtime.IPath;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.dltk.core.environment.IDeployment;
import org.eclipse.dltk.core.environment.IFileHandle;
import org.eclipse.dltk.internal.launching.AbstractInterpreterInstallType;
import org.eclipse.dltk.launching.IInterpreterInstall;

public class OctaveInterpreterInstallType extends AbstractInterpreterInstallType {

	protected String getBuildPathDelimeter() {
		return File.pathSeparator;
	}
	
	protected String[] readPathsFromProcess(IProgressMonitor monitor, Process p) {
		final BufferedReader dataIn = new BufferedReader(new InputStreamReader(
				p.getInputStream()));
		final List result = new ArrayList();
		final Object lock = new Object();
		Thread tReading = new Thread(new Runnable() {
			public void run() {
				try {
					result.add(dataIn.readLine());
					synchronized (lock) {
						lock.notifyAll();
					}
				} catch (IOException e) {
				}
			}
		});
		tReading.start();
		synchronized (lock) {
			try {
				lock.wait(5000);
			} catch (InterruptedException e) {
			}
			p.destroy();
		}
		return (String[]) result.toArray(new String[result.size()]);
	}
	
	protected String[] buildCommandLine(IFileHandle installLocation,
			IFileHandle pathFile) {
		return new String[] { installLocation.getCanonicalPath(), "-q", pathFile.getCanonicalPath() };
	}
	
	protected IPath createPathFile(IDeployment deployment) throws IOException {
		return null;
	}

	protected IInterpreterInstall doCreateInterpreterInstall(String id) {
		return new OctaveInterpreterInstall(this, id);
	}

	protected ILog getLog() {
		return OctavePlugin.getDefault().getLog();
	}

	protected String getPluginId() {
		return OctavePlugin.PLUGIN_ID;
	}

	protected String[] getPossibleInterpreterNames() {
		return new String[]{"octave"};
	}

	public String getName() {
		return "Octave Installation Type";
	}

	public String getNatureId() {
		return OctaveNature.OCTAVE_NATURE;
	}
}
