package octclipse.text;

import org.eclipse.dltk.ui.text.ScriptSourceViewerConfiguration;
import org.eclipse.dltk.ui.text.ScriptTextTools;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.jface.text.IDocument;
import org.eclipse.jface.text.IDocumentExtension3;
import org.eclipse.jface.text.IDocumentPartitioner;
import org.eclipse.jface.text.rules.IPartitionTokenScanner;
import org.eclipse.ui.texteditor.ITextEditor;

public class OctaveTextTools extends ScriptTextTools {

	private IPartitionTokenScanner scanner;
	private final static String[] LEGAL_CONTENT_TYPES = IOctavePartitions.OCTAVE_PARTITION_TYPES;
	
	public OctaveTextTools(boolean autoDisposeOnDisplayDispose) {
		super(IOctavePartitions.OCTAVE_PARTITIONING, LEGAL_CONTENT_TYPES, autoDisposeOnDisplayDispose);
		scanner = new OctavePartitionScanner();
	}

	public ScriptSourceViewerConfiguration createSourceViewerConfiguraton(
			IPreferenceStore preferenceStore, ITextEditor editor,
			String partitioning) {
		return new OctaveSourceViewerConfiguration(getColorManager(), 
				preferenceStore, editor, partitioning);
	}
	
	public IPartitionTokenScanner getPartitionScanner() {
		return scanner;
	}
	
	public void setupDocumentPartitioner(IDocument document, String partitioning) {
		IDocumentPartitioner partitioner = createDocumentPartitioner();
		if (partitioner != null) {
			partitioner.connect(document);
			if (document instanceof IDocumentExtension3) {
				IDocumentExtension3 extension3 = (IDocumentExtension3) document;
				extension3.setDocumentPartitioner(partitioning, partitioner);
			} else {
				document.setDocumentPartitioner(partitioner);
			}
		}
	}
}
